Extended docs and a library of examples are available
at:

http://mmb.irbbarcelona.org/molywood

### What does `molywood` do?

Molywood is there to make cool molecular movies for you.

Specifically, `molywood` automatizes the most tedious steps in
generation of these movies, i.e. scripting in TCL, rendering, generating
overlays and combining frames, as well as merging frames into the final
movie.

We try to simplify the movie making syntax, as well as add extended
functionalities such as animating trajectory data with matplotlib,
adding insets or making multi-panel movies.

The basic idea behind the functionalities of `molywood` is best understood
through the examples hosted on ... Ambitious users are advised to
familiarize themselves with the documentation of individual keywords,
and explore the capabilities of the script through experimentation.

### Installation

The simplest way to install `molywood` is through `pip`:

`pip install molywood`

will install the script as a command-line tool, so that on most Unix-based
systems `molywood` can be run right away with an example input:

`molywood movie_script.txt`

If any dependencies are missing (e.g., on a remote cluster or workstation),
you can use `conda` to automatically install them and create a virtual
environment. After installation with `pip`, just run 

`molywood-gen-env`

in your command line to (a) automatically look for missing dependencies
and (b) directly download them from `conda` channels if there are any. Even when installing
VMD, you won't need root privileges - everything is managed through your
private `conda` package manager. When the virtual environment is set up,
type:

`source activate molywood`

(or `conda activate molywood`, depending on your `conda` setup). If the virtual
environment is not activated, `molywood` will try to activate it on-the-fly
whenever VMD cannot be found in the system path.

#### Manual installation of dependencies

Full functionality requires that `python3`, `VMD`, `imagemagick` and
`ffmpeg` be installed. The good news is that the actual rendering can be done externally,
e.g. on a remote workstation, once you set up the visualization state
locally. Using the draft mode with `render=f` (see below), you can also
preview your movie only with `python3` and `VMD`.

Alternatively, all dependencies can be installed separately:
+ It is recommended to use `python3` from the Anaconda distribution
as it contains `numpy` and `matplotlib` as a pre-installed package.
+ `VMD` can be obtained at `https://www.ks.uiuc.edu/Research/vmd/`.
+ `imagemagick` is installed by default on most Linux distributions;
run e.g. `convert` to make sure it is available on your machine.
+ `ffmpeg` can be installed e.g. from the Ubuntu repository by
typing `sudo apt-get install ffmpeg`.

### Usage

Sample movie scripts are available in the `examples` directory: try
them first to see how the library works.

`molywood` can be run from the console (e.g. in the `examples/simple_movie`
directory) as:

 `python ../../molywood/moly.py script.txt`

In general, to run `molywood` the following files are needed:

1. either (a) a visualization state generated by VMD, or (b) a structure
file; (a) is the preferred way - user may define the representations
as well as set the camera angle as desired, and then go to File > Save
Visualization State); in option (b), a default representation is used,
and a compatible trajectory file can be provided. Alternatively, one can
provide a four-character `pdb_code=...`, and the structure will be
automatically downloaded from the PDB database.
1. a 'movie script', i.e. a simple text file containing directives,
including a reference to the VMD visualization state (see examples and
the explanations below).

### Full documentation

Follow these links for: 
+ [the documentation of all individual keywords](http://mmb.irbbarcelona.org/molywood/docs), 
+ [minimal video examples for each feature](http://mmb.irbbarcelona.org/molywood/samples),
+ [video tutorials](http://mmb.irbbarcelona.org/molywood/tutorials), and
+ [a featured movie gallery](http://mmb.irbbarcelona.org/molywood/tutorials). 

### Featured movies

If you believe your `molywood`-generated movie should be featured in our gallery
to inspire other users, please email your example (input file, the rendered movie, 
and possibly other files, such as your structure/trajectory and the .vmd 
visualization state) to [this address](mailto:milafternoon@gmail.com). You may also
include a literature reference to highlight your work.
